@@ -69,15 +69,33 @@ class FreqDict(models.Model):
     def loadWF(self):
         wfs = self.loadOrthWF()
         wfs = self.loadTransWF(wfs)
+        wfss = []
         for key in wfs:
             lem = Lemma.objects.filter(pk=int(wfs[key]['IdLemma']))
             if len(lem) != 1:
                 continue
-            wf = WordForm.objects.create(pk=int(key),Lemma = lem[0],Frequency = int(wfs[key]['Freq']))
-            ss = (Orthography.objects.get_or_create(Spelling=s)[0] for s in wfs[key]['Spellings'])
-            wf.Orthographies.add(*ss)
-            ts = (Transcription.objects.get_or_create(Transcription=t)[0] for t in wfs[key]['Transcriptions'])
-            wf.Transcriptions.add(*ts)
+            wfss.append(WordForm(pk=int(key),Lemma = lem[0],Frequency = int(wfs[key]['Freq']))
+        WordForm.objects.bulk_create(wfss)
+        for w in wfss:
+            #ts = [Transcription(Transcription=t
+            #        ,CVSkel=re.sub('[^IE{VQU@i#$u312456789cq0~]','C',
+            #                    re.sub('[IE{VQU@i#$u312456789cq0~]','V',
+            #                        re.sub(r'[-"\']','',t))))
+            #            for t in wfs[w.pk]['Transcriptions']]
+            #Transcription.objects.bulk_create(ts)
+            #w.Transcriptions.add(*ts)
+            #ss = [Orthography(Spelling=s) for s in wfs[w.pk]['Spellings']]
+            #Orthography.objects.bulk_create(ss)
+            #w.Orthographies.add(*ss)
+            #wf = WordForm.objects.create(pk=int(key),Lemma = lem[0],Frequency = int(wfs[key]['Freq']))
+            ss = (Orthography.objects.get_or_create(Spelling=s)[0] for s in wfs[w.pk]['Spellings'])
+            w.Orthographies.add(*ss)
+            ts = (Transcription.objects.get_or_create(Transcription=t
+                    ,CVSkel=re.sub('[^IE{VQU@i#$u312456789cq0~]','C',
+                                re.sub('[IE{VQU@i#$u312456789cq0~]','V',
+                                    re.sub(r'[-"\']','',t))))[0]
+                        for t in wfs[w.pk]['Transcriptions'])
+            w.Transcriptions.add(*ts)
 
     def loadOrthLemmas(self):
         lemmas = {}
@@ -227,6 +245,9 @@ class Transcription(models.Model):
     def __unicode__(self):
         return self.Transcription
 
+    def stripTranscription(self):
+        return self.Transcription.replace('-','').replace("'",'').replace('"','')
+
     #def getCVStruct(self):
     #    if self.CVSkel is not None:
     #        return self.CVSkel
@@ -253,10 +274,10 @@ class WordForm(models.Model):
     Frequency = models.FloatField(blank=True,null=True)
 
     def getTranscriptions(self):
-        return ".".join(str(t) for t in wf.Transcriptions.all())
+        return ".".join(str(t) for t in self.Transcriptions.all())
 
     def getSpellings(self):
-        return ", ".join(str(s) for s in wf.Orthographies.all())
+        return ", ".join(str(s) for s in self.Orthographies.all())
 
     def __unicode__(self):
         return u'%s' % self.Lemma.Label
