@@ -63,12 +63,43 @@ def reset(request):
                 c = FreqDict.objects.create(Name='CELEX')
                 c.loadInfo()
                 return redirect(index)
-            else:
-                form = ResetForm()
-                render(request,'celex/form.html',{'form':form})
-        else:
-            form = ResetForm()
-            return render(request,'celex/form.html',{'form':form})
+        form = ResetForm()
+        return render(request,'celex/form.html',{'form':form})
+
+@login_required
+def string_selection(request):
+    if request.method == 'POST':
+        form = StringForm(request.POST)
+        if form.is_valid() and form.cleaned_data['reset']:
+            response = HttpResponse(mimetype='text/csv')
+            response['Content-Disposition'] = 'attachment; filename="strings.csv"'
+            writer = csv.writer(response)
+            qs = WordForm.objects.all()
+            qs = qs.filter(Lemma__Category__in = form.cleaned_data['categories']).prefetch_related()
+            if form.cleaned_data['exclude_punctuation']:
+                qs = qs.exclude(Orthographies__Spelling__contains="'")
+                qs = qs.exclude(Orthographies__Spelling__contains=".")
+                qs = qs.exclude(Orthographies__Spelling__contains=",")
+                qs = qs.exclude(Orthographies__Spelling__contains='"')
+            if form.cleaned_data['exclude_titlecase']:
+                qs = qs.exclude(Orthographies__Spelling__regex="^[A-Z]")
+            #if form.cleaned_data['phone_length'] != '0':
+            #    qs = filter(lambda q: len(q.Transcriptions.
+            qs = qs.filter(Transcriptions__CVSkel = forms.cleaned_data['cvskel'])
+            for q in qs:
+                if len(q.Transcriptions.all() != 1:
+                    continue
+                t = q.Transcriptions.all()[0]
+                s = q.Orthographies.all()[0]
+                f = q.Frequency
+                c = q.Lemma.Category.Label
+                L = q.Lemma.Label
+                LF = q.Lemma.Frequency
+                writer.writerow([s,t,c,f,L,LF])
+            return response
+    form = StringForm()
+    return render(request,'celex/form.html',{'form':form})
+
 
 #def getFreqBreaks(qs):
     #freqs = sorted(qs.values_list('Frequency',flat=True))
